#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_BITWISE_AND_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_BITWISE_AND_HPP_INCLUDED

#include <boost/simd/operator/include/functions/bitwise_and.hpp>

#endif
